:mod:`{{module}}`.{{objname}}
{{ underline }}====================

.. currentmodule:: {{ module }}

.. autofunction:: {{ objname }}

.. Not needed since there is no "Examples" section in the docstrings
.. .. include:: {{module}}.{{objname}}.examples

.. raw:: html

    <div class="clearer"></div>
